@@ -24,10 +24,14 @@ from ..usecases.car_damage_detection import CarDamageConfig, CarDamageDetectionU
 from ..usecases.age_detection import AgeDetectionUseCase, AgeDetectionConfig
 from ..usecases.weld_defect_detection import WeldDefectUseCase,WeldDefectConfig
 from ..usecases.price_tag_detection import PriceTagUseCase, PriceTagConfig
+from ..usecases.mask_detection import MaskDetectionConfig, MaskDetectionUseCase
+from ..usecases.banana_defect_detection import BananaMonitoringUseCase,BananaMonitoringConfig
+from ..usecases.distracted_driver_detection import DistractedDriverUseCase, DistractedDriverConfig
 
 __all__ = [
     'PeopleCountingUseCase',
     'CustomerServiceUseCase',
+    'BananaMonitoringUseCase',
     'AdvancedCustomerServiceUseCase',
     'BasicCountingTrackingUseCase',
     'LicensePlateUseCase',
@@ -38,6 +42,7 @@ __all__ = [
     'PotholeSegmentationUseCase',
     'ParkingSpaceUseCase',
     'FlareAnalysisUseCase',
+    'MaskDetectionUseCase',
     'CarDamageDetectionUseCase',
     'FaceEmotionUseCase',
     'UnderwaterPlasticUseCase',
@@ -45,8 +50,10 @@ __all__ = [
     'AgeDetectionUseCase',
     'WeldDefectUseCase',
     'PriceTagUseCase',
+    'DistractedDriverUseCase',
     'PeopleCountingConfig',
     'PotholeConfig',
+    'BananaMonitoringConfig',
     'CustomerServiceConfig',
     'AdvancedCustomerServiceConfig',
     'PPEComplianceConfig',
@@ -54,6 +61,7 @@ __all__ = [
     'ColorDetectionConfig',
     'VehicleMonitoringConfig',
     'ParkingSpaceConfig',
+    'MaskDetectionConfig',
     'FireSmokeConfig',
     'CarDamageConfig',
     'FlareAnalysisConfig',
@@ -62,5 +70,6 @@ __all__ = [
     'PedestrianDetectionConfig',
     'AgeDetectionConfig',
     'WeldDefectConfig',
-    'PriceTagConfig'
+    'PriceTagConfig',
+    'DistractedDriverConfig'
 ]
