@@ -36,6 +36,8 @@ from .usecases import (
     PotholeSegmentationUseCase,
     PPEComplianceUseCase,
     VehicleMonitoringUseCase,
+    BananaMonitoringUseCase,
+    MaskDetectionUseCase,
     CarDamageDetectionUseCase,
     FireSmokeUseCase,
     FlareAnalysisUseCase,
@@ -48,7 +50,8 @@ from .usecases import (
     WeldDefectUseCase,
 
     AgeDetectionUseCase,
-    PriceTagUseCase
+    PriceTagUseCase,
+    DistractedDriverUseCase
 
 
 )
@@ -121,6 +124,8 @@ class PostProcessor:
         registry.register_use_case("car_damage", "car_damage_detection", CarDamageDetectionUseCase)
 
         registry.register_use_case("traffic", "vehicle_monitoring", VehicleMonitoringUseCase)
+        registry.register_use_case("traffic", "fruit_monitoring", BananaMonitoringUseCase)
+        
         registry.register_use_case("hazard", "fire_smoke_detection", FireSmokeUseCase)
         registry.register_use_case("flare_detection", "flare_analysis", FlareAnalysisUseCase)
         registry.register_use_case("general", "face_emotion", FaceEmotionUseCase)
@@ -130,6 +135,8 @@ class PostProcessor:
         registry.register_use_case("security", "age_detection", AgeDetectionUseCase)
         registry.register_use_case("weld", "weld_defect_detection", WeldDefectUseCase)
         registry.register_use_case("price_tag", "price_tag_detection", PriceTagUseCase)
+        registry.register_use_case("mask_detection", "mask_detection", MaskDetectionUseCase)
+        registry.register_use_case("automobile", "distracted_driver_detection", DistractedDriverUseCase)
         
         logger.debug("Registered use cases with registry")
     
@@ -224,6 +231,8 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, input_bytes, context, stream_info)
             elif isinstance(use_case, VehicleMonitoringUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, BananaMonitoringUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, FlareAnalysisUseCase):
                 result = use_case.process(data, parsed_config,input_bytes, context, stream_info)
             elif isinstance(use_case,LicensePlateUseCase):
