@@ -23,10 +23,12 @@ from .pedestrian_detection import PedestrianDetectionUseCase, PedestrianDetectio
 from .age_detection import AgeDetectionUseCase, AgeDetectionConfig
 
 from .weld_defect_detection import WeldDefectConfig,WeldDefectUseCase
+from .banana_defect_detection import BananaMonitoringUseCase,BananaMonitoringConfig
 
 from .car_damage_detection import CarDamageConfig, CarDamageDetectionUseCase
 from .price_tag_detection import PriceTagConfig, PriceTagUseCase
 from .mask_detection import MaskDetectionConfig, MaskDetectionUseCase
+from .distracted_driver_detection import DistractedDriverUseCase, DistractedDriverConfig
 
 
 __all__ = [
@@ -37,6 +39,7 @@ __all__ = [
     'LicensePlateUseCase',
     'ColorDetectionUseCase',
     'PPEComplianceUseCase',
+    'BananaMonitoringUseCase',
     'VehicleMonitoringUseCase',
     'ParkingSpaceUseCase',
     'FireSmokeUseCase',
@@ -50,6 +53,7 @@ __all__ = [
     'AgeDetectionUseCase',
     'WeldDefectUseCase',
     'PriceTagUseCase',
+    'DistractedDriverUseCase',
     'PeopleCountingConfig',
     'ParkingSpaceConfig',
     'CustomerServiceConfig',
@@ -67,6 +71,8 @@ __all__ = [
     'UnderwaterPlasticConfig',
     'PedestrianDetectionConfig',
     'AgeDetectionConfig',
+    'BananaMonitoringConfig',
     'WeldDefectConfig',
-    'PriceTagConfig'
+    'PriceTagConfig',
+    'DistractedDriverConfig',
 ]
\ No newline at end of file
